@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AUTOCORRECTIONTEST_H
-#define AUTOCORRECTIONTEST_H
+#pragma once
 
 #include <KSharedConfig>
 #include <QObject>
@@ -48,4 +47,3 @@ private:
     KSharedConfig::Ptr mConfig;
 };
 
-#endif // AUTOCORRECTIONTEST_H
