@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -35,9 +35,9 @@ private:
     void slotEnableLogActivities(bool state);
     void slotActivityTextChanged(bool changed);
 
-    LogActivitiesWidget *mLogWidget = nullptr;
+    LogActivitiesWidget *const mLogWidget;
     QPushButton *mClearButton = nullptr;
-    QCheckBox *mEnableLogActivities = nullptr;
+    QCheckBox *const mEnableLogActivities;
     QPushButton *mSaveButton = nullptr;
     QPushButton *mShareButton = nullptr;
 };
