@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SIEVETEMPLATEEDITDIALOG_H
-#define SIEVETEMPLATEEDITDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -39,4 +38,3 @@ private:
 };
 }
 
-#endif // TEMPLATEEDITDIALOG_H
