@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,9 +9,7 @@
 #include <QComboBox>
 using namespace PimCommon;
 
-TranslatorUtil::TranslatorUtil()
-{
-}
+TranslatorUtil::TranslatorUtil() = default;
 
 QPair<QString, QString> TranslatorUtil::pair(TranslatorUtil::languages lang)
 {
