@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,7 +24,6 @@
 #include <QKeyEvent>
 #include <QLabel>
 #include <QMimeData>
-#include <QNetworkConfigurationManager>
 #include <QPainter>
 #include <QShortcut>
 #include <QSplitter>
@@ -32,13 +31,14 @@
 #include <QVBoxLayout>
 
 using namespace PimCommon;
-
+namespace
+{
+static const char myTranslatorWidgetConfigGroupName[] = "TranslatorWidget";
+}
 class Q_DECL_HIDDEN TranslatorWidget::TranslatorWidgetPrivate
 {
 public:
-    TranslatorWidgetPrivate()
-    {
-    }
+    TranslatorWidgetPrivate() = default;
 
     ~TranslatorWidgetPrivate()
     {
@@ -159,12 +159,11 @@ TranslatorWidget::~TranslatorWidget()
     disconnect(d->inputText, &TranslatorTextEdit::textChanged, this, &TranslatorWidget::slotTextChanged);
     disconnect(d->inputText, &TranslatorTextEdit::translateText, this, &TranslatorWidget::slotTranslate);
     writeConfig();
-    delete d;
 }
 
 void TranslatorWidget::writeConfig()
 {
-    KConfigGroup myGroup(KSharedConfig::openConfig(), "TranslatorWidget");
+    KConfigGroup myGroup(KSharedConfig::openConfig(), myTranslatorWidgetConfigGroupName);
     if (d->languageSettingsChanged) {
         myGroup.writeEntry(QStringLiteral("FromLanguage"), d->from->itemData(d->from->currentIndex()).toString());
         myGroup.writeEntry("ToLanguage", d->to->itemData(d->to->currentIndex()).toString());
@@ -175,7 +174,7 @@ void TranslatorWidget::writeConfig()
 
 void TranslatorWidget::readConfig()
 {
-    KConfigGroup myGroup(KSharedConfig::openConfig(), "TranslatorWidget");
+    KConfigGroup myGroup(KSharedConfig::openConfig(), myTranslatorWidgetConfigGroupName);
     const QString from = myGroup.readEntry(QStringLiteral("FromLanguage"));
     const QString to = myGroup.readEntry(QStringLiteral("ToLanguage"));
     if (from.isEmpty()) {
@@ -202,7 +201,7 @@ void TranslatorWidget::init()
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateFailed, this, &TranslatorWidget::slotTranslateFailed);
 
     auto layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
     auto hboxLayout = new QHBoxLayout;
     auto closeBtn = new QToolButton(this);
     closeBtn->setObjectName(QStringLiteral("close-button"));
@@ -294,11 +293,11 @@ void TranslatorWidget::init()
     slotFromLanguageChanged(0, true);
     slotTextChanged();
     readConfig();
-    connect(d->from, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this](int val) {
+    connect(d->from, &QComboBox::currentIndexChanged, this, [this](int val) {
         slotFromLanguageChanged(val, false);
         slotConfigChanged();
     });
-    connect(d->to, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this]() {
+    connect(d->to, &QComboBox::currentIndexChanged, this, [this]() {
         slotConfigChanged();
         slotTranslate();
     });
@@ -344,7 +343,7 @@ void TranslatorWidget::setTextToTranslate(const QString &text)
 
 void TranslatorWidget::slotTranslate()
 {
-    if (!PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline()) {
+    if (!PimCommon::NetworkManager::self()->isOnline()) {
         KMessageBox::information(this, i18n("No network connection detected, we cannot translate text."), i18n("No network"));
         return;
     }
