@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef COLLECTIONACLWIDGET_H
-#define COLLECTIONACLWIDGET_H
+#pragma once
 
 #include <QWidget>
 class QCheckBox;
@@ -33,4 +32,3 @@ private:
 };
 }
 
-#endif // COLLECTIONACLWIDGET_H
