@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef BLACKLISTBALOOEMAILSEARCHJOB_H
-#define BLACKLISTBALOOEMAILSEARCHJOB_H
+#pragma once
 
 #include <QObject>
 
@@ -35,4 +34,3 @@ private:
 };
 }
 
-#endif // BLACKLISTBALOOEMAILSEARCHJOB_H
