@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -14,11 +14,8 @@ class ContentTypeWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit ContentTypeWidgetTest(QObject *parent = nullptr);
-    ~ContentTypeWidgetTest();
+    ~ContentTypeWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
-    void shouldChangeComboBoxIndex();
-    void shouldEmitSignalWhenIndexChanged();
-    void shouldChangeItem();
 };
 
