@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -13,10 +13,8 @@ class IncidencesForWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit IncidencesForWidgetTest(QObject *parent = nullptr);
-    ~IncidencesForWidgetTest();
+    ~IncidencesForWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
-    void shouldChangeComboBoxIndex();
-    void shouldEmitSignalWhenIndexChanged();
 };
 
